from setuptools import setup

setup(name='distributions_ms_dsnd',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_ms_dsnd'],
      author = 'Mehreen Samad',
      author_email = 'mehreen.samad@gmail.com',
      zip_safe=False)
